# QTMimport
This small module opens data files generated by the QTMtoolbox (.csv format) and parses the data into a single object (class).
Each variable that was measured is an attribute of this class, and contains the header name, data, etc. 

### Dependencies
This module uses **numpy**.

### Usage
To import the module, use 
```
from qtmimport import qtmimport
```

Then, to parse data, use
```
data_object = qtmimport.parse_data(filename)
```

The `data_object` will contain data in the following form:
```
Data structure:
    
    list QTMdata:
        |
        |--> class "variable"
                |
                |--> index (must be unique!)
                |
                |--> header name (not unique, e.g. for <sweep> when 
                |                 you both sweep and read a variable)
                |
                |--> data array 
				|--> variable type (s = SETpoint, g = GET value (measured value))
```
